==> gwenview-trinity_3.5.13.2.orig.tar.xz: gwenview-trinity-3.5.13.2/src/app/testvtabwidget.cpp <==
// vim: set tabstop=4 shiftwidth=4 noexpandtab:
// kate: indent-mode csands; indent-width 4; replace-tabs-save off; replace-tabs off; replace-trailing-space-save off; space-indent off; tabs-indents on; tab-width 4;
/*
Gwenview - A simple image viewer for KDE
Copyright 2005 Aurelien Gateau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/
// TQt
#include <tqlabel.h>

// KDE
#include <kapplication.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <kiconloader.h>

// Local
#include <vtabwidget.h>

int main(int argc, char* argv[]) {
	KAboutData aboutData("testvtabwidget", "testvtabwidget", "0");
	KCmdLineArgs::init( argc, argv, &aboutData );
	KApplication app;

	Gwenview::VTabWidget tabWidget(0);
	TQLabel* lbl=new TQLabel("label 1", &tabWidget);
	tabWidget.addTab(lbl, SmallIcon("text"), "tab1");
	lbl=new TQLabel("label 2", &tabWidget);
	tabWidget.addTab(lbl, SmallIcon("image"), "tab2");
	
	app.setMainWidget(&tabWidget);
	tabWidget.show();
	app.exec();
}

==> gwenview-trinity-14.0.7.tar.xz: gwenview-trinity-14.0.7/src/app/testvtabwidget.cpp <==
// vim: set tabstop=4 shiftwidth=4 noexpandtab:
// kate: indent-mode csands; indent-width 4; replace-tabs-save off; replace-tabs off; replace-trailing-space-save off; space-indent off; tabs-indents on; tab-width 4;
/*
Gwenview - A simple image viewer for TDE
Copyright 2005 Aurelien Gateau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/
// TQt
#include <tqlabel.h>

// KDE
#include <tdeapplication.h>
#include <tdeaboutdata.h>
#include <tdecmdlineargs.h>
#include <kiconloader.h>

// Local
#include <vtabwidget.h>

int main(int argc, char* argv[]) {
	TDEAboutData aboutData("testvtabwidget", "testvtabwidget", "0");
	TDECmdLineArgs::init( argc, argv, &aboutData );
	TDEApplication app;

	Gwenview::VTabWidget tabWidget(0);
	TQLabel* lbl=new TQLabel("label 1", &tabWidget);
	tabWidget.addTab(lbl, SmallIcon("text"), "tab1");
	lbl=new TQLabel("label 2", &tabWidget);
	tabWidget.addTab(lbl, SmallIcon("image-x-generic"), "tab2");
	
	app.setMainWidget(&tabWidget);
	tabWidget.show();
	app.exec();
}
